@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-"""サーバー関連
-
+"""watchdog server.
 """
 from __future__ import print_function
 from __future__ import unicode_literals
@@ -9,8 +8,6 @@ from __future__ import generators
 from __future__ import division
 import logging
 
-import time
-
 from watchdog.observers import Observer
 from watchdog.events import PatternMatchingEventHandler
 
@@ -20,7 +17,6 @@ from . import app
 class ReloadServer(object):
     def __init__(self):
         self.observer = None
-
         self.is_monitor = False
 
     def start(self, target_path, target_module):
@@ -30,14 +26,10 @@ class ReloadServer(object):
         self.observer.start()
         self.is_monitor = True
 
-        try:
-            while self.is_monitor:
-                time.sleep(3)
-        finally:
-            self.observer.stop()
-            self.observer.join()
-
     def stop(self):
+        self.observer.stop()
+        self.observer.join()
+
         self.is_monitor = False
 
 
@@ -56,7 +48,3 @@ class MayaModuleReloadEventhandler(PatternMatchingEventHandler):
         self.logger.info("================================================")
 
         app.remove_include_module(self.reload_target_name)
-
-
-class SingletonMultiInstanceError(Exception):
-    pass
